/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "view_common.h"

#define ENGINE_ITEM_INDEX 0
#define ENGINE_ITEM_COUNT 2
#define FORMAT_ITEM_INDEX ENGINE_ITEM_INDEX+ENGINE_ITEM_COUNT
#define FORMAT_ITEM_COUNT 7
#define VERSION_ITEM_INDEX FORMAT_ITEM_INDEX+FORMAT_ITEM_COUNT
#define VERSION_ITEM_COUNT 3
#define ITEMS_COUNT ENGINE_ITEM_COUNT+FORMAT_ITEM_COUNT+VERSION_ITEM_COUNT

static struct view_info {
	char *description;
	char *feature_key;
} s_info[ITEMS_COUNT] = {
		{"Engine",					NULL},
		{"OpenGL ES",				"http://tizen.org/feature/opengles"},
		{"Format",					NULL},
		{"3DC Texture Format",		"http://tizen.org/feature/opengles.texture_format.3dc"},
		{"ATC Texture Format",		"http://tizen.org/feature/opengles.texture_format.atc"},
		{"ETC Texture Format",		"http://tizen.org/feature/opengles.texture_format.etc"},
		{"PTC Texture Format",		"http://tizen.org/feature/opengles.texture_format.ptc"},
		{"PVRTC Texture Format",	"http://tizen.org/feature/opengles.texture_format.pvrtc"},
		{"UTC Texture Format",		"http://tizen.org/feature/opengles.texture_format.utc"},
		{"Version",					NULL},
		{"OpenGL v.1.1",			"http://tizen.org/feature/opengles.version.1_1"},
		{"OpenGL v.2.0",			"http://tizen.org/feature/opengles.version.2_0"},
};

static char *_item_text_get_cb(void *data, Evas_Object *obj, const char *part);

/**
 * @brief Callback function which creates the 'OpenGL' item sub-view.
 * This callback function is invoked on 'OpenGL' item selection from the main view.
 * @param[in] data The user data passed to the elm_list_item_append() function.
 * @param[in] obj The object invoking this callback function.
 * @param[in] event_info The structure containing the information on this event.
 */
void view_opengl_list_cb(void *data, Evas_Object *obj, void *event_info)
{
	if (!view_create_subview((Evas_Object *)data, "OpenGL", 0, _item_text_get_cb))
		return;

	view_create_subview_group(ENGINE_ITEM_INDEX, ENGINE_ITEM_COUNT, _item_text_get_cb);
	view_create_subview_group(FORMAT_ITEM_INDEX, FORMAT_ITEM_COUNT, _item_text_get_cb);
	view_create_subview_group(VERSION_ITEM_INDEX, VERSION_ITEM_COUNT, _item_text_get_cb);
}

/**
 * @brief Internal callback function invoked on genlist item display.
 * This function is assigned to the func.text_get handler of genlist item's class structure.
 * The item's area consists if two labels:
 * - top label where the feature description is displayed,
 * - bottom label where the feature's status is displayed.
 * @param[in] data The user data passed to the elm_genlist_item_append() function.
 * @param[in] obj The object invoking this callback function.
 * @param[in] part The name of the item's part being rendered.
 * @return The text string to be displayed is returned.
 */
static char *_item_text_get_cb(void *data, Evas_Object *obj, const char *part)
{
	int index = (int)data;
	char buf[MAX_STR] = {0,};
	bool value;

	if (!strcmp(part, "elm.text")) {
		return strdup(s_info[index].description);
	} else if (!strcmp(part, "elm.text.sub")) {
		value = data_get_feature_state(s_info[index].feature_key);
		snprintf(buf, MAX_STR, "%s", value ? "Supported" : "Not Supported");
		return strdup(buf);
	}

	return NULL;
}
